@@ -1,10 +1,11 @@
 import sys
-sys.path.append('..')
+sys.path.append("..")
 import harness
 
-def proc (mod) :
+
+def proc(mod):
     x = mod.H()
-    for i in range(10000000) :
+    for i in range(10000000):
         x.func()
 
 harness.run(proc)
