@@ -33,5 +33,22 @@ public class cpp11_move_typemaps_runme {
       if (!exception_thrown)
         throw new ApplicationException("double usage of take should have been an error");
     }
+
+    Counter.reset_counts();
+    using (InstanceMethodsTester imt = new InstanceMethodsTester()) {
+      using (MoveOnly mo = new MoveOnly(333)) {
+        Counter.check_counts(1, 0, 0, 0, 0, 0);
+        imt.instance_take_move_only(mo);
+        Counter.check_counts(1, 0, 0, 1, 0, 2);
+      }
+      Counter.check_counts(1, 0, 0, 1, 0, 2);
+      Counter.reset_counts();
+      using (MovableCopyable mc = new MovableCopyable(444)) {
+        Counter.check_counts(1, 0, 0, 0, 0, 0);
+        imt.instance_take_movable_copyable(mc);
+        Counter.check_counts(1, 0, 0, 1, 0, 2);
+      }
+      Counter.check_counts(1, 0, 0, 1, 0, 2);
+    }
   }
 }
