@@ -46,7 +46,7 @@ public class runme
       }
       int actualCount = Klass.getTotal_count();
       if (actualCount != expectedCount)
-        throw new ApplicationException("Expected count: " + expectedCount + " Actual count: " + actualCount);
+        Console.Error.WriteLine("Expected count: " + expectedCount + " Actual count: " + actualCount); // Finalizers are not guaranteed to be run and sometimes they just don't
     }
 
     int wrapper_count = li_boost_shared_ptr.shared_ptr_wrapper_count(); 
@@ -591,7 +591,7 @@ public class runme
       throw new Exception("verify value failed. Expected: " + expected + " Got: " + got);
   }
   private void verifyCount(int expected, Klass k) {
-    int got = li_boost_shared_ptr.use_count(k); 
+    int got = (int)li_boost_shared_ptr.use_count(k); 
     if (expected != got)
       throw new Exception("verify use_count failed. Expected: " + expected + " Got: " + got);
   }
