@@ -1,6 +1,6 @@
 package main
 
-import . "./namespace_typemap"
+import . "swigtests/namespace_typemap"
 
 func main() {
 	if Stest1("hello") != "hello" {
@@ -51,7 +51,7 @@ func main() {
 		panic(0)
 	}
 
-	c := cmplx(float64(2), float64(3))
+	c := complex(2, 3)
 	r := real(c)
 
 	if Ctest1(c) != r {
