@@ -21,6 +21,7 @@ public class director_thread_runme {
     if (d.getVal() >= 0) {
         throw new RuntimeException("Failed. Val: " + d.getVal());
     }
+    d.stop();
   }
 }
 
@@ -30,6 +31,12 @@ class director_thread_Derived extends Foo {
   }
 
   public void do_foo() {
+    // Not all operating systems can name threads, so only test on those that can
+    if (Foo.namedThread()) {
+      String threadName = Thread.currentThread().getName();
+      if (!threadName.equals("MyThreadName"))
+        throw new RuntimeException("Unexpected thread name: " + threadName);
+    }
     setVal(getVal() - 1);
   }
 }
