@@ -11,7 +11,7 @@ a1 = a_ptr(a);
 a2 = a_ptr(a);
 
 if (swig_this(a1) != swig_this(a2))
-  error
+  error("failed");
 endif
   
 
@@ -20,7 +20,7 @@ xstr1 = printf("0x%x",lthis);
 xstr2 = pointer_str(a);
 
 if (xstr1 != xstr2)
-  error
+  error("failed");
 endif
 
 s = str(a.this);
@@ -29,5 +29,5 @@ r = repr(a.this);
 v1 = v_ptr(a);
 v2 = v_ptr(a);
 if (uint64(v1) != uint64(v2))
-  error
+  error("failed");
 endif
