@@ -1,10 +1,10 @@
 typemap_namespace
 
 if (!strcmp(test1("hello"),"hello"))
-    error
+    error("failed");
 endif
 
 if (!strcmp(test2("hello"),"hello"))
-    error
+    error("failed");
 endif
 
