@@ -1,9 +1,9 @@
 <?php
 
 require "tests.php";
-require "php_iterator.php";
 
-check::functions(array('myiterator_rewind','myiterator_key','myiterator_current','myiterator_next','myiterator_valid'));
+// No new functions.
+check::functions(array());
 check::classes(array('MyIterator'));
 // No new global variables.
 check::globals(array());
@@ -21,4 +21,3 @@ foreach (new MyIterator(2, 5) as $k => $v) {
 check::equal($s, '(0=>2)(1=>3)(2=>4)', 'Simple iteration failed');
 
 check::done();
-?>
