@@ -1,7 +1,6 @@
 <?php
 
 require "tests.php";
-require "typedef_reference.php";
 
 check::functions(array('somefunc','otherfunc','new_intp','copy_intp','delete_intp','intp_assign','intp_value'));
 $int2=copy_intp(2);
@@ -10,4 +9,3 @@ $int3=copy_intp(3);
 check::equal(3,otherfunc($int3)," test passing intp to otherfunc");
 
 check::done();
-?>
