@@ -8,4 +8,4 @@ y = b.blah()
 
 a = dynamic_cast.do_test(y)
 if a != "Bar::test":
-    print "Failed!!"
+    raise RuntimeError("Failed!!")
