@@ -31,7 +31,6 @@ struct Scanner {
   int     start_line;		/* Starting line of certain declarations */
   int     line;
   int     yylen;	        /* Length of text pushed into text */
-  String *file;
   String *error;                /* Last error message (if any) */
   int     error_line;           /* Error line number */
   int     freeze_line;          /* Suspend line number updates */
@@ -58,7 +57,6 @@ Scanner *NewScanner(void) {
   Scanner *s;
   s = (Scanner *) Malloc(sizeof(Scanner));
   s->line = 1;
-  s->file = 0;
   s->nexttoken = -1;
   s->start_line = 1;
   s->yylen = 0;
@@ -85,7 +83,6 @@ void DelScanner(Scanner *s) {
   Delete(s->scanobjs);
   Delete(s->brackets);
   Delete(s->text);
-  Delete(s->file);
   Delete(s->error);
   Delete(s->str);
   Free(s->idstart);
@@ -113,7 +110,6 @@ void Scanner_clear(Scanner *s) {
   s->yylen = 0;
   /* Should these be cleared too?
   s->idstart;
-  s->file;
   s->error_line;
   s->freeze_line;
   */
@@ -209,26 +205,26 @@ void Scanner_idstart(Scanner *s, const char *id) {
 /* -----------------------------------------------------------------------------
  * nextchar()
  * 
- * Returns the next character from the scanner or 0 if end of the string.
+ * Returns the next character from the scanner or EOF if end of the string.
  * ----------------------------------------------------------------------------- */
-static char nextchar(Scanner *s) {
+static int nextchar(Scanner *s) {
   int nc;
   if (!s->str)
-    return 0;
+    return EOF;
   while ((nc = Getc(s->str)) == EOF) {
     Delete(s->str);
     s->str = 0;
     Delitem(s->scanobjs, 0);
     if (Len(s->scanobjs) == 0)
-      return 0;
+      return EOF;
     s->str = Getitem(s->scanobjs, 0);
     s->line = Getline(s->str);
     DohIncref(s->str);
   }
   if ((nc == '\n') && (!s->freeze_line)) 
     s->line++;
-  Putc(nc,s->text);
-  return (char)nc;
+  Putc(nc, s->text);
+  return nc;
 }
 
 /* -----------------------------------------------------------------------------
@@ -397,7 +393,7 @@ static void get_escape(Scanner *s) {
 
   while (1) {
     c = nextchar(s);
-    if (c == 0)
+    if (c == EOF)
       break;
     switch (state) {
     case 0:
@@ -442,6 +438,9 @@ static void get_escape(Scanner *s) {
 	return;
       }
       if (c == 'e') {
+	// '\e' is a non-standard alternative to '\033' (the escape character)
+	// in both C and C++, but is supported by at least GCC and clang.  MSVC
+	// issues a warning and treats it as an 'e'.
 	Delitem(s->text, DOH_END);
 	Append(s->text,"\033");
 	return;
@@ -474,14 +473,22 @@ static void get_escape(Scanner *s) {
 	return;
       }
       break;
-    case 10:
-      if (!isdigit(c)) {
+    case 10: // Second digit of octal escape sequence
+    case 11: // Third digit of octal escape sequence
+      if (c < '0' || c > '7') {
 	retract(s,1);
 	Putc((char)result,s->text);
 	return;
       }
       result = (result << 3) + (c - '0');
       Delitem(s->text, DOH_END);
+      if (state == 11) {
+	if (result > 255)
+	  Swig_error(Scanner_file(s), Scanner_line(s), "octal escape sequence out of range\n");
+	Putc((char)result,s->text);
+	return;
+      }
+      state = 11;
       break;
     case 20:
       if (!isxdigit(c)) {
@@ -519,7 +526,7 @@ static int look(Scanner *s) {
   while (1) {
     switch (state) {
     case 0:
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return (0);
 
       /* Process delimiters */
@@ -536,7 +543,7 @@ static int look(Scanner *s) {
       break;
 
     case 1000:
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
         return (0);
       if (c == '%')
 	state = 4;		/* Possibly a SWIG directive */
@@ -612,7 +619,7 @@ static int look(Scanner *s) {
       else if (c == ':')
 	state = 5;		/* maybe double colon */
       else if (c == '0')
-	state = 83;		/* An octal or hex value */
+	state = 83;		/* Maybe a hex, octal or binary number */
       else if (c == '\"') {
 	state = 2;              /* A string constant */
 	s->start_line = s->line;
@@ -641,7 +648,7 @@ static int look(Scanner *s) {
       break;
 
     case 1:			/*  Comment block */
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return (0);
       if (c == '/') {
 	state = 10;		/* C++ style comment */
@@ -663,7 +670,7 @@ static int look(Scanner *s) {
       }
       break;
     case 10:			/* C++ style comment */
-      if ((c = nextchar(s)) == 0) {
+      if ((c = nextchar(s)) == EOF) {
 	Swig_error(cparse_file, cparse_start_line, "Unterminated comment\n");
 	return SWIG_TOKEN_ERROR;
       }
@@ -675,7 +682,7 @@ static int look(Scanner *s) {
       }
       break;
     case 11:			/* C style comment block */
-      if ((c = nextchar(s)) == 0) {
+      if ((c = nextchar(s)) == EOF) {
 	Swig_error(cparse_file, cparse_start_line, "Unterminated comment\n");
 	return SWIG_TOKEN_ERROR;
       }
@@ -686,7 +693,7 @@ static int look(Scanner *s) {
       }
       break;
     case 12:			/* Still in C style comment */
-      if ((c = nextchar(s)) == 0) {
+      if ((c = nextchar(s)) == EOF) {
 	Swig_error(cparse_file, cparse_start_line, "Unterminated comment\n");
 	return SWIG_TOKEN_ERROR;
       }
@@ -705,7 +712,7 @@ static int look(Scanner *s) {
 	break;
       }
       
-      if ((c = nextchar(s)) == 0) {
+      if ((c = nextchar(s)) == EOF) {
 	Swig_error(cparse_file, cparse_start_line, "Unterminated string\n");
 	return SWIG_TOKEN_ERROR;
       }
@@ -719,7 +726,7 @@ static int look(Scanner *s) {
       break;
 
     case 20:			/* Inside the string */
-      if ((c = nextchar(s)) == 0) {
+      if ((c = nextchar(s)) == EOF) {
 	Swig_error(cparse_file, cparse_start_line, "Unterminated string\n");
 	return SWIG_TOKEN_ERROR;
       }
@@ -736,7 +743,7 @@ static int look(Scanner *s) {
 	if (c==')') {
 	  int i=0;
 	  String *end_delimiter = NewStringEmpty();
-	  while ((c = nextchar(s)) != 0 && c!='\"') {
+	  while ((c = nextchar(s)) != EOF && c != '\"') {
 	    Putc( (char)c, end_delimiter );
 	    i++;
 	  }
@@ -750,7 +757,7 @@ static int look(Scanner *s) {
 	    str_delimiter = 0;
 	    return SWIG_TOKEN_STRING;
 	  } else {                   /* Incorrect end delimiter occurred */
-	    if (c == 0) {
+	    if (c == EOF) {
 	      Swig_error(cparse_file, cparse_start_line, "Unterminated raw string, started with R\"%s( is not terminated by )%s\"\n", str_delimiter, str_delimiter);
 	      return SWIG_TOKEN_ERROR;
 	    }
@@ -763,7 +770,7 @@ static int look(Scanner *s) {
       break;
 
     case 3:			/* Maybe a not equals */
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_LNOT;
       else if (c == '=')
 	return SWIG_TOKEN_NOTEQUAL;
@@ -774,7 +781,7 @@ static int look(Scanner *s) {
       break;
 
     case 31:			/* AND or Logical AND or ANDEQUAL */
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_AND;
       else if (c == '&')
 	return SWIG_TOKEN_LAND;
@@ -787,7 +794,7 @@ static int look(Scanner *s) {
       break;
 
     case 32:			/* OR or Logical OR */
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_OR;
       else if (c == '|')
 	return SWIG_TOKEN_LOR;
@@ -800,7 +807,7 @@ static int look(Scanner *s) {
       break;
 
     case 33:			/* EQUAL or EQUALTO */
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_EQUAL;
       else if (c == '=')
 	return SWIG_TOKEN_EQUALTO;
@@ -811,7 +818,7 @@ static int look(Scanner *s) {
       break;
 
     case 4:			/* A wrapper generator directive (maybe) */
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_PERCENT;
       if (c == '{') {
 	state = 40;		/* Include block */
@@ -834,7 +841,7 @@ static int look(Scanner *s) {
       break;
 
     case 40:			/* Process an include block */
-      if ((c = nextchar(s)) == 0) {
+      if ((c = nextchar(s)) == EOF) {
 	Swig_error(cparse_file, cparse_start_line, "Unterminated block\n");
 	return SWIG_TOKEN_ERROR;
       }
@@ -842,7 +849,7 @@ static int look(Scanner *s) {
 	state = 41;
       break;
     case 41:			/* Still processing include block */
-      if ((c = nextchar(s)) == 0) {
+      if ((c = nextchar(s)) == EOF) {
 	set_error(s,s->start_line,"Unterminated code block");
 	return 0;
       }
@@ -858,7 +865,7 @@ static int look(Scanner *s) {
 
     case 5:			/* Maybe a double colon */
 
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_COLON;
       if (c == ':')
 	state = 50;
@@ -869,7 +876,7 @@ static int look(Scanner *s) {
       break;
 
     case 50:			/* DCOLON, DCOLONSTAR */
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_DCOLON;
       else if (c == '*')
 	return SWIG_TOKEN_DCOLONSTAR;
@@ -880,14 +887,14 @@ static int look(Scanner *s) {
       break;
 
     case 60:			/* shift operators */
-      if ((c = nextchar(s)) == 0) {
+      if ((c = nextchar(s)) == EOF) {
 	brackets_increment(s);
 	return SWIG_TOKEN_LESSTHAN;
       }
       if (c == '<')
 	state = 240;
       else if (c == '=') {
-	if ((c = nextchar(s)) == 0) {
+	if ((c = nextchar(s)) == EOF) {
 	  return SWIG_TOKEN_LTEQUAL;
 	} else if (c == '>' && cparse_cplusplus) { /* Spaceship operator */
 	  return SWIG_TOKEN_LTEQUALGT;
@@ -902,7 +909,7 @@ static int look(Scanner *s) {
       }
       break;
     case 61:
-      if ((c = nextchar(s)) == 0) {
+      if ((c = nextchar(s)) == EOF) {
         brackets_decrement(s);
 	return SWIG_TOKEN_GREATERTHAN;
       }
@@ -931,7 +938,7 @@ static int look(Scanner *s) {
 	break;
       }
       
-      if ((c = nextchar(s)) == 0) {
+      if ((c = nextchar(s)) == EOF) {
 	state = 76;
       }
       else if (c == '\"') { /* Definitely u, U or L string */
@@ -955,7 +962,7 @@ static int look(Scanner *s) {
       break;
 
     case 70:			/* Identifier */
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	state = 76;
       else if (isalnum(c) || (c == '_') || (c == '$')) {
 	state = 70;
@@ -966,7 +973,7 @@ static int look(Scanner *s) {
       break;
     
     case 71:			/* Possibly u8 string/char */
-      if ((c = nextchar(s)) == 0) {
+      if ((c = nextchar(s)) == EOF) {
 	state = 76;
       }
       else if (c=='\"') {
@@ -990,7 +997,7 @@ static int look(Scanner *s) {
     case 72:			/* Possibly CUSTOM DELIMITER string */
     case 73:
     case 74:
-      if ((c = nextchar(s)) == 0) {
+      if ((c = nextchar(s)) == EOF) {
 	state = 76;
       }
       else if (c=='\"') {
@@ -1014,7 +1021,7 @@ static int look(Scanner *s) {
       break;
 
     case 75:			/* Special identifier $ */
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_DOLLAR;
       if (isalnum(c) || (c == '_') || (c == '*') || (c == '&')) {
 	state = 70;
@@ -1025,17 +1032,40 @@ static int look(Scanner *s) {
       }
       break;
 
-    case 76:			/* Identifier or true/false */
+    case 76:			/* Identifier, true/false or alternative token */
       if (cparse_cplusplus) {
 	if (Strcmp(s->text, "true") == 0)
 	  return SWIG_TOKEN_BOOL;
-	else if (Strcmp(s->text, "false") == 0)
+	if (Strcmp(s->text, "false") == 0)
 	  return SWIG_TOKEN_BOOL;
+
+	if (Strcmp(s->text, "and") == 0)
+	  return SWIG_TOKEN_LAND;
+	if (Strcmp(s->text, "and_eq") == 0)
+	  return SWIG_TOKEN_ANDEQUAL;
+	if (Strcmp(s->text, "bitand") == 0)
+	  return SWIG_TOKEN_AND;
+	if (Strcmp(s->text, "bitor") == 0)
+	  return SWIG_TOKEN_OR;
+	if (Strcmp(s->text, "compl") == 0)
+	  return SWIG_TOKEN_NOT;
+	if (Strcmp(s->text, "not") == 0)
+	  return SWIG_TOKEN_LNOT;
+	if (Strcmp(s->text, "not_eq") == 0)
+	  return SWIG_TOKEN_NOTEQUAL;
+	if (Strcmp(s->text, "or") == 0)
+	  return SWIG_TOKEN_LOR;
+	if (Strcmp(s->text, "or_eq") == 0)
+	  return SWIG_TOKEN_OREQUAL;
+	if (Strcmp(s->text, "xor") == 0)
+	  return SWIG_TOKEN_XOR;
+	if (Strcmp(s->text, "xor_eq") == 0)
+	  return SWIG_TOKEN_XOREQUAL;
       }
       return SWIG_TOKEN_ID;
 
     case 77: /*identifier or wide string literal*/
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_ID;
       else if (c == '\"') {
 	s->start_line = s->line;
@@ -1056,7 +1086,7 @@ static int look(Scanner *s) {
     break;
 
     case 78:			/* Processing a wide string literal*/
-      if ((c = nextchar(s)) == 0) {
+      if ((c = nextchar(s)) == EOF) {
 	Swig_error(cparse_file, cparse_start_line, "Unterminated wide string\n");
 	return SWIG_TOKEN_ERROR;
       }
@@ -1064,15 +1094,13 @@ static int look(Scanner *s) {
 	Delitem(s->text, DOH_END);
 	return SWIG_TOKEN_WSTRING;
       } else if (c == '\\') {
-	if ((c = nextchar(s)) == 0) {
-	  Swig_error(cparse_file, cparse_start_line, "Unterminated wide string\n");
-	  return SWIG_TOKEN_ERROR;
-	}
+	Delitem(s->text, DOH_END);
+	get_escape(s);
       }
       break;
 
     case 79:			/* Processing a wide char literal */
-      if ((c = nextchar(s)) == 0) {
+      if ((c = nextchar(s)) == EOF) {
 	Swig_error(cparse_file, cparse_start_line, "Unterminated wide character constant\n");
 	return SWIG_TOKEN_ERROR;
       }
@@ -1080,22 +1108,19 @@ static int look(Scanner *s) {
 	Delitem(s->text, DOH_END);
 	return (SWIG_TOKEN_WCHAR);
       } else if (c == '\\') {
-	if ((c = nextchar(s)) == 0) {
-	  Swig_error(cparse_file, cparse_start_line, "Unterminated wide character literal\n");
-	  return SWIG_TOKEN_ERROR;
-	}
+	Delitem(s->text, DOH_END);
+	get_escape(s);
       }
       break;
 
     case 8:			/* A numerical digit */
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_INT;
       if (c == '.') {
 	state = 81;
       } else if ((c == 'e') || (c == 'E')) {
 	state = 82;
       } else if ((c == 'f') || (c == 'F')) {
-	Delitem(s->text, DOH_END);
 	return SWIG_TOKEN_FLOAT;
       } else if (isdigit(c)) {
 	state = 8;
@@ -1109,14 +1134,13 @@ static int look(Scanner *s) {
       }
       break;
     case 81:			/* A floating pointer number of some sort */
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_DOUBLE;
       if (isdigit(c))
 	state = 81;
       else if ((c == 'e') || (c == 'E'))
 	state = 820;
       else if ((c == 'f') || (c == 'F')) {
-	Delitem(s->text, DOH_END);
 	return SWIG_TOKEN_FLOAT;
       } else if ((c == 'l') || (c == 'L')) {
 	Delitem(s->text, DOH_END);
@@ -1127,7 +1151,7 @@ static int look(Scanner *s) {
       }
       break;
     case 82:
-      if ((c = nextchar(s)) == 0) {
+      if ((c = nextchar(s)) == EOF) {
 	Swig_error(cparse_file, cparse_start_line, "Exponent does not have any digits\n");
 	return SWIG_TOKEN_ERROR;
       }
@@ -1141,7 +1165,7 @@ static int look(Scanner *s) {
       break;
     case 820:
       /* Like case 82, but we've seen a decimal point. */
-      if ((c = nextchar(s)) == 0) {
+      if ((c = nextchar(s)) == EOF) {
 	Swig_error(cparse_file, cparse_start_line, "Exponent does not have any digits\n");
 	return SWIG_TOKEN_ERROR;
       }
@@ -1154,8 +1178,8 @@ static int look(Scanner *s) {
       }
       break;
     case 83:
-      /* Might be a hexadecimal or octal number */
-      if ((c = nextchar(s)) == 0)
+      /* Might be a hexadecimal, octal or binary number */
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_INT;
       if (isdigit(c))
 	state = 84;
@@ -1178,7 +1202,10 @@ static int look(Scanner *s) {
       break;
     case 84:
       /* This is an octal number */
-      if ((c = nextchar(s)) == 0)
+      if (c == '8' || c == '9') {
+	Swig_error(Scanner_file(s), Scanner_line(s), "Invalid digit '%c' in octal constant\n", c);
+      }
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_INT;
       if (isdigit(c))
 	state = 84;
@@ -1197,7 +1224,7 @@ static int look(Scanner *s) {
       break;
     case 85:
       /* This is an hex number */
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_INT;
       if (isxdigit(c))
 	state = 85;
@@ -1216,11 +1243,13 @@ static int look(Scanner *s) {
       break;
     case 850:
       /* This is a binary number */
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_INT;
       if ((c == '0') || (c == '1'))
 	state = 850;
-      else if ((c == 'l') || (c == 'L')) {
+      else if (isdigit(c)) {
+	Swig_error(Scanner_file(s), Scanner_line(s), "Invalid digit '%c' in binary constant\n", c);
+      } else if ((c == 'l') || (c == 'L')) {
 	state = 87;
       } else if ((c == 'u') || (c == 'U')) {
 	state = 88;
@@ -1231,7 +1260,7 @@ static int look(Scanner *s) {
       break;
     case 860:
       /* hexadecimal float */
-      if ((c = nextchar(s)) == 0) {
+      if ((c = nextchar(s)) == EOF) {
 	Swig_error(cparse_file, cparse_start_line, "Hexadecimal floating literals require an exponent\n");
 	return SWIG_TOKEN_ERROR;
       }
@@ -1248,12 +1277,11 @@ static int look(Scanner *s) {
     case 86:
       /* Rest of floating point number */
 
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_DOUBLE;
       if (isdigit(c))
 	state = 86;
       else if ((c == 'f') || (c == 'F')) {
-	Delitem(s->text, DOH_END);
 	return SWIG_TOKEN_FLOAT;
       } else if ((c == 'l') || (c == 'L')) {
 	Delitem(s->text, DOH_END);
@@ -1266,7 +1294,7 @@ static int look(Scanner *s) {
 
     case 87:
       /* A long integer of some sort */
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_LONG;
       if ((c == 'u') || (c == 'U')) {
 	return SWIG_TOKEN_ULONG;
@@ -1281,7 +1309,7 @@ static int look(Scanner *s) {
       /* A long long integer */
 
     case 870:
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_LONGLONG;
       if ((c == 'u') || (c == 'U')) {
 	return SWIG_TOKEN_ULONGLONG;
@@ -1293,7 +1321,7 @@ static int look(Scanner *s) {
       /* An unsigned number */
     case 88:
 
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_UINT;
       if ((c == 'l') || (c == 'L')) {
 	state = 880;
@@ -1305,7 +1333,7 @@ static int look(Scanner *s) {
 
       /* Possibly an unsigned long long or unsigned long */
     case 880:
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_ULONG;
       if ((c == 'l') || (c == 'L'))
 	return SWIG_TOKEN_ULONGLONG;
@@ -1316,7 +1344,7 @@ static int look(Scanner *s) {
 
       /* A character constant */
     case 9:
-      if ((c = nextchar(s)) == 0) {
+      if ((c = nextchar(s)) == EOF) {
 	Swig_error(cparse_file, cparse_start_line, "Unterminated character constant\n");
 	return SWIG_TOKEN_ERROR;
       }
@@ -1332,7 +1360,7 @@ static int look(Scanner *s) {
       /* A period or an ellipsis or maybe a floating point number */
 
     case 100:
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return (0);
       if (isdigit(c))
 	state = 81;
@@ -1347,7 +1375,7 @@ static int look(Scanner *s) {
       /* An ellipsis */
 
     case 101:
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return (0);
       if (c == '.') {
 	return SWIG_TOKEN_ELLIPSIS;
@@ -1360,7 +1388,7 @@ static int look(Scanner *s) {
     /* A left bracket or a double left bracket */
     case 102:
 
-      if ((c = nextchar(s)) == 0) {
+      if ((c = nextchar(s)) == EOF) {
         return SWIG_TOKEN_LBRACKET;
       } else if (c == '[') {
         return SWIG_TOKEN_LLBRACKET;
@@ -1372,7 +1400,7 @@ static int look(Scanner *s) {
 
     /* a right bracket or a double right bracket */
     case 103:
-      if ((c = nextchar(s)) == 0) {
+      if ((c = nextchar(s)) == EOF) {
         return SWIG_TOKEN_RBRACKET;
       } else if (c == ']') {
         return SWIG_TOKEN_RRBRACKET;
@@ -1383,7 +1411,7 @@ static int look(Scanner *s) {
       break;
 
     case 200:			/* PLUS, PLUSPLUS, PLUSEQUAL */
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_PLUS;
       else if (c == '+')
 	return SWIG_TOKEN_PLUSPLUS;
@@ -1396,7 +1424,7 @@ static int look(Scanner *s) {
       break;
 
     case 210:			/* MINUS, MINUSMINUS, MINUSEQUAL, ARROW */
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_MINUS;
       else if (c == '-')
 	return SWIG_TOKEN_MINUSMINUS;
@@ -1411,7 +1439,7 @@ static int look(Scanner *s) {
       break;
 
     case 211:			/* ARROW, ARROWSTAR */
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_ARROW;
       else if (c == '*')
 	return SWIG_TOKEN_ARROWSTAR;
@@ -1423,7 +1451,7 @@ static int look(Scanner *s) {
 
 
     case 220:			/* STAR, TIMESEQUAL */
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_STAR;
       else if (c == '=')
 	return SWIG_TOKEN_TIMESEQUAL;
@@ -1434,7 +1462,7 @@ static int look(Scanner *s) {
       break;
 
     case 230:			/* XOR, XOREQUAL */
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_XOR;
       else if (c == '=')
 	return SWIG_TOKEN_XOREQUAL;
@@ -1445,7 +1473,7 @@ static int look(Scanner *s) {
       break;
 
     case 240:			/* LSHIFT, LSEQUAL */
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_LSHIFT;
       else if (c == '=')
 	return SWIG_TOKEN_LSEQUAL;
@@ -1456,7 +1484,7 @@ static int look(Scanner *s) {
       break;
 
     case 250:			/* RSHIFT, RSEQUAL */
-      if ((c = nextchar(s)) == 0)
+      if ((c = nextchar(s)) == EOF)
 	return SWIG_TOKEN_RSHIFT;
       else if (c == '=')
 	return SWIG_TOKEN_RSEQUAL;
@@ -1468,7 +1496,7 @@ static int look(Scanner *s) {
 
       /* Reverse string */
     case 900:
-      if ((c = nextchar(s)) == 0) {
+      if ((c = nextchar(s)) == EOF) {
 	Swig_error(cparse_file, cparse_start_line, "Unterminated character constant\n");
 	return SWIG_TOKEN_ERROR;
       }
@@ -1526,21 +1554,19 @@ String *Scanner_text(Scanner *s) {
  * ----------------------------------------------------------------------------- */
 
 void Scanner_skip_line(Scanner *s) {
-  char c;
-  int done = 0;
   Clear(s->text);
   Setfile(s->text, Getfile(s->str));
   Setline(s->text, s->line);
-  while (!done) {
-    if ((c = nextchar(s)) == 0)
+  while (1) {
+    int c;
+    if ((c = nextchar(s)) == EOF)
       return;
     if (c == '\\') {
       nextchar(s);
     } else if (c == '\n') {
-      done = 1;
+      return;
     }
   }
-  return;
 }
 
 /* -----------------------------------------------------------------------------
@@ -1586,6 +1612,12 @@ int Scanner_skip_balanced(Scanner *s, int startchar, int endchar) {
       num_levels++;
     } else if (tok == endtok) {
       if (--num_levels == 0) break;
+    } else if (tok == SWIG_TOKEN_RRBRACKET && endtok == SWIG_TOKEN_RBRACKET) {
+      num_levels -= 2;
+      if (num_levels <= 0) {
+	if (num_levels < 0) Scanner_pushtoken(s, SWIG_TOKEN_RBRACKET, "]");
+	break;
+      }
     } else if (tok == SWIG_TOKEN_COMMENT) {
       char *loc = Char(s->text);
       if (strncmp(loc, "/*@SWIG", 7) == 0 && loc[Len(s->text)-3] == '@') {
@@ -1687,7 +1719,7 @@ int Scanner_isoperator(int tokval) {
 }
 
 /* ----------------------------------------------------------------------
- * locator()
+ * Scanner_locator()
  *
  * Support for locator strings. These are strings of the form
  * @SWIG:filename,line,id@ emitted by the SWIG preprocessor.  They
